<a id="question-anchor-{{ question.id }}" class="question">{{ question.text }}
    <img id="question-image-{{ question.id }}" class="question_image" src="{{ MEDIA_URL }}{{ question.header_picture }}"></a>
<div id="question-answer-{{ question.id }}" class="question_answer">
    {% autoescape off %}
        {{ question.answer_text }}
    {% endautoescape %}
</div>

